==> skrooge_0.6.0.orig.tar.gz: skrooge-0.6.0/tests/suite_squish/tst_create_unit/test.py <==
def main():
    source(findFile("scripts", "skrooge_functions.py"))
    initSimple()
    
    waitForObject(":Untitled [modified] - skrooge_KTabBar")
    type(":Untitled [modified] - skrooge_KTabBar", "<Ctrl+0>")
    waitForObject(":Skrooge unit plugin.Manual_QToolButton")
    clickButton(":Skrooge unit plugin.Manual_QToolButton")
    waitForObject(":kNameCreatorUnit_KLineEdit")
    mouseClick(":kNameCreatorUnit_KLineEdit", 89, 8, 0, Qt.LeftButton)
    waitForObject(":kNameCreatorUnit_KLineEdit")
    type(":kNameCreatorUnit_KLineEdit", "GOOG")
    waitForObject(":kNameCreatorUnit_KLineEdit")
    type(":kNameCreatorUnit_KLineEdit", "<Tab>")
    waitForObject(":kSymbolCreatorUnit_KLineEdit")
    type(":kSymbolCreatorUnit_KLineEdit", "GOOG")
    waitForObject(":kSymbolCreatorUnit_KLineEdit")
    type(":kSymbolCreatorUnit_KLineEdit", "<Tab>")
    waitForObject(":kTypeCreatorUnit_SKGComboBox")
    type(":kTypeCreatorUnit_SKGComboBox", "<Down>")
    waitForObject(":kTypeCreatorUnit_SKGComboBox")
    type(":kTypeCreatorUnit_SKGComboBox", "<Down>")
    waitForObject(":kTypeCreatorUnit_SKGComboBox")
    type(":kTypeCreatorUnit_SKGComboBox", "<Down>")
    waitForObject(":kTypeCreatorUnit_SKGComboBox")
    type(":kTypeCreatorUnit_SKGComboBox", "<Tab>")
    waitForObject(":kUnitCreatorUnit_SKGComboBox")
    sendEvent("QKeyEvent", ":kUnitCreatorUnit_SKGComboBox", QEvent.KeyRelease, 16777236, 0, 0, "", False, 1)
    waitForObject(":kUnitCreatorUnit_SKGComboBox")
    type(":kUnitCreatorUnit_SKGComboBox", "<Down>")
    waitForObject(":kUnitCreatorUnit_SKGComboBox")
    type(":kUnitCreatorUnit_SKGComboBox", "<Tab>")
    waitForObject(":kCountryCreatorUnit_KLineEdit")
    type(":kCountryCreatorUnit_KLineEdit", "<Tab>")
    waitForObject(":kInternetCreatorUnit_KLineEdit")
    type(":kInternetCreatorUnit_KLineEdit", "GOOG")
    waitForObject(":kBtnFrm.Add_KPushButton_2")
    clickButton(":kBtnFrm.Add_KPushButton_2")
    waitForObject(":kCountryCreatorUnit_KLineEdit")
    mouseClick(":kCountryCreatorUnit_KLineEdit", 446, 8, 0, Qt.LeftButton)
    waitForObject(":kCountryCreatorUnit_KLineEdit")
    type(":kCountryCreatorUnit_KLineEdit", "US")
    waitForObject(":kBtnFrm.Update_KPushButton_2")
    clickButton(":kBtnFrm.Update_KPushButton_2")
    waitForObject(":Skrooge unit plugin.Download_KPushButton")
    clickButton(":Skrooge unit plugin.Download_KPushButton")
    waitForObject(":Skrooge unit plugin.Download_KPushButton")
    doubleClick(":Skrooge unit plugin.Download_KPushButton", 46, 6, 0, Qt.LeftButton)
    waitForObject(":Untitled [modified] - skrooge.Open report_QToolButton")
    clickButton(":Untitled [modified] - skrooge.Open report_QToolButton")
    waitForObject(":kLines_SKGComboBox")
    sendEvent("QKeyEvent", ":kLines_SKGComboBox", QEvent.KeyPress, 87, 23, 67108864, "", False, 1)
    waitForObject(":Skrooge unit plugin.Values_QToolButton")
    clickButton(":Skrooge unit plugin.Values_QToolButton")
    waitForObject(":kAmountEdit_SKGCalculatorEdit")
    mouseClick(":kAmountEdit_SKGCalculatorEdit", 30, 17, 0, Qt.LeftButton)
    waitForObject(":kAmountEdit_SKGCalculatorEdit")
    type(":kAmountEdit_SKGCalculatorEdit", "<5>")
    waitForObject(":kAmountEdit_SKGCalculatorEdit")
    type(":kAmountEdit_SKGCalculatorEdit", "<0>")
    waitForObject(":kAmountEdit_SKGCalculatorEdit")
    type(":kAmountEdit_SKGCalculatorEdit", "<0>")
    waitForObject(":kBtnFrm.Add_KPushButton_2")
    clickButton(":kBtnFrm.Add_KPushButton_2")
    waitForObject(":kAmountEdit_SKGCalculatorEdit")
    type(":kAmountEdit_SKGCalculatorEdit", "<Alt+/>")
    waitForObject(":Split share – Skrooge.OK_KPushButton")
    sendEvent("QMouseEvent", ":Split share – Skrooge.OK_KPushButton", QEvent.MouseButtonPress, 46, 19, Qt.LeftButton, 0)
    waitForObject(":Split share – Skrooge.OK_KPushButton")
    sendEvent("QMouseEvent", ":Split share – Skrooge.OK_KPushButton", QEvent.MouseButtonRelease, 46, 19, Qt.LeftButton, 1)
    waitForObject(":kAmountEdit_SKGCalculatorEdit")
    sendEvent("QKeyEvent", ":kAmountEdit_SKGCalculatorEdit", QEvent.KeyPress, 48, 48, 603979776, "0", False, 1)
    waitForObject(":Untitled [modified] - skrooge_KTabBar")
    type(":Untitled [modified] - skrooge_KTabBar", "<Ctrl+1>")
    
    bookmarkAndRemoveCurrentPage()
    
    waitForObject(":Untitled [modified] - skrooge_KTabBar")
    type(":Untitled [modified] - skrooge_KTabBar", "<Ctrl+W>")
    waitForObject(":Untitled [modified] - skrooge_KTabBar")
    type(":Untitled [modified] - skrooge_KTabBar", "<Ctrl+0>")
    
    bookmarkAndRemoveCurrentPage()
    
    waitForObject(":kMainSplitter.Units_SKGTableView")
    mouseClick(":kMainSplitter.Units_SKGTableView", 365, 254, 0, Qt.LeftButton)
    waitForObject(":kMainSplitter.Units_SKGTableView")
    type(":kMainSplitter.Units_SKGTableView", "<Ctrl+A>")
    waitForObject(":Untitled [modified] - skrooge.Delete_QToolButton")
    clickButton(":Untitled [modified] - skrooge.Delete_QToolButton")
    waitForObject(":Untitled [modified] - skrooge_SKGMainPanel")
    sendEvent("QCloseEvent", ":Untitled [modified] - skrooge_SKGMainPanel")
    waitForObject(":Question – Skrooge.Do not save_KPushButton")
    clickButton(":Question – Skrooge.Do not save_KPushButton")

==> skrooge_0.7.2.2.orig.tar.gz: skrooge-0.7.2.2/tests/suite_squish/tst_create_unit/test.py <==
# -*- coding: utf-8 -*-
def main():
    source(findFile("scripts", "skrooge_functions.py"))
    initSimple()

    waitForObject(":Untitled [modified] - skrooge_KTabBar")
    type(":Untitled [modified] - skrooge_KTabBar", "<Ctrl+Alt+0>")
    waitForObject(":Skrooge unit plugin.Manual_QToolButton")
    clickButton(":Skrooge unit plugin.Manual_QToolButton")
    waitForObject(":kNameCreatorUnit_KLineEdit")
    mouseClick(":kNameCreatorUnit_KLineEdit", 89, 8, 0, Qt.LeftButton)
    waitForObject(":kNameCreatorUnit_KLineEdit")
    type(":kNameCreatorUnit_KLineEdit", "GOOG")
    waitForObject(":kNameCreatorUnit_KLineEdit")
    type(":kNameCreatorUnit_KLineEdit", "<Tab>")
    waitForObject(":kSymbolCreatorUnit_KLineEdit")
    type(":kSymbolCreatorUnit_KLineEdit", "GOOG")
    waitForObject(":kSymbolCreatorUnit_KLineEdit")
    type(":kSymbolCreatorUnit_KLineEdit", "<Tab>")
    waitForObject(":kTypeCreatorUnit_SKGComboBox")
    type(":kTypeCreatorUnit_SKGComboBox", "<Down>")
    waitForObject(":kTypeCreatorUnit_SKGComboBox")
    type(":kTypeCreatorUnit_SKGComboBox", "<Down>")
    waitForObject(":kTypeCreatorUnit_SKGComboBox")
    type(":kTypeCreatorUnit_SKGComboBox", "<Down>")
    waitForObject(":kTypeCreatorUnit_SKGComboBox")
    type(":kTypeCreatorUnit_SKGComboBox", "<Tab>")
    waitForObject(":kUnitCreatorUnit_SKGComboBox")
    sendEvent("QKeyEvent", ":kUnitCreatorUnit_SKGComboBox", QEvent.KeyRelease, 16777236, 0, 0, "", False, 1)
    waitForObject(":kUnitCreatorUnit_SKGComboBox")
    type(":kUnitCreatorUnit_SKGComboBox", "<Down>")
    waitForObject(":kUnitCreatorUnit_SKGComboBox")
    type(":kUnitCreatorUnit_SKGComboBox", "<Tab>")
    waitForObject(":kCountryCreatorUnit_KLineEdit")
    type(":kCountryCreatorUnit_KLineEdit", "<Tab>")
    waitForObject(":kInternetCreatorUnit_KLineEdit")
    type(":kInternetCreatorUnit_KLineEdit", "GOOG")
    waitForObject(":kBtnFrm.Add_KPushButton_2")
    clickButton(":kBtnFrm.Add_KPushButton_2")
    waitForObject(":kCountryCreatorUnit_KLineEdit")
    mouseClick(":kCountryCreatorUnit_KLineEdit", 446, 8, 0, Qt.LeftButton)
    waitForObject(":kCountryCreatorUnit_KLineEdit")
    type(":kCountryCreatorUnit_KLineEdit", "US")
    waitForObject(":kBtnFrm.Update_KPushButton_2")
    clickButton(":kBtnFrm.Update_KPushButton_2")
    waitForObject(":Skrooge unit plugin.Download_KPushButton")
    clickButton(":Skrooge unit plugin.Download_KPushButton")

    snooze(5)

    waitForObject(":Untitled [modified] - skrooge.Open report_QToolButton")
    clickButton(":Untitled [modified] - skrooge.Open report_QToolButton")
    waitForObject(":kLines_SKGComboBox")
    sendEvent("QKeyEvent", ":kLines_SKGComboBox", QEvent.KeyPress, 87, 23, 67108864, "", False, 1)
    waitForObject(":Skrooge unit plugin.Values_QToolButton")
    clickButton(":Skrooge unit plugin.Values_QToolButton")
    waitForObject(":kAmountEdit_SKGCalculatorEdit")
    mouseClick(":kAmountEdit_SKGCalculatorEdit", 30, 17, 0, Qt.LeftButton)
    waitForObject(":kAmountEdit_SKGCalculatorEdit")
    type(":kAmountEdit_SKGCalculatorEdit", "<5>")
    waitForObject(":kAmountEdit_SKGCalculatorEdit")
    type(":kAmountEdit_SKGCalculatorEdit", "<0>")
    waitForObject(":kAmountEdit_SKGCalculatorEdit")
    type(":kAmountEdit_SKGCalculatorEdit", "<0>")
    waitForObject(":kBtnFrm.Add_KPushButton_2")
    clickButton(":kBtnFrm.Add_KPushButton_2")
    waitForObject(":kAmountEdit_SKGCalculatorEdit")
    type(":kAmountEdit_SKGCalculatorEdit", "<Alt+/>")
    waitForObject(":Split share – Skrooge.OK_KPushButton")
    sendEvent("QMouseEvent", ":Split share – Skrooge.OK_KPushButton", QEvent.MouseButtonPress, 46, 19, Qt.LeftButton, 0)
    waitForObject(":Split share – Skrooge.OK_KPushButton")
    sendEvent("QMouseEvent", ":Split share – Skrooge.OK_KPushButton", QEvent.MouseButtonRelease, 46, 19, Qt.LeftButton, 1)
    waitForObject(":kAmountEdit_SKGCalculatorEdit")
    sendEvent("QKeyEvent", ":kAmountEdit_SKGCalculatorEdit", QEvent.KeyPress, 48, 48, 603979776, "0", False, 1)
    waitForObject(":Untitled [modified] - skrooge_KTabBar")
    type(":Untitled [modified] - skrooge_KTabBar", "<Ctrl+1>")

    bookmarkAndRemoveCurrentPage()

    waitForObject(":Untitled [modified] - skrooge_KTabBar")
    type(":Untitled [modified] - skrooge_KTabBar", "<Ctrl+W>")
    waitForObject(":Untitled [modified] - skrooge_KTabBar")
    type(":Untitled [modified] - skrooge_KTabBar", "<Ctrl+0>")

    bookmarkAndRemoveCurrentPage()

    waitForObject(":kMainSplitter.Units_SKGTableView")
    mouseClick(":kMainSplitter.Units_SKGTableView", 365, 254, 0, Qt.LeftButton)
    waitForObject(":kMainSplitter.Units_SKGTableView")
    type(":kMainSplitter.Units_SKGTableView", "<Ctrl+A>")
    waitForObject(":Untitled [modified] - skrooge.Delete_QToolButton")
    clickButton(":Untitled [modified] - skrooge.Delete_QToolButton")
    
    snooze(1)
    
    waitForObject(":Untitled [modified] - skrooge_SKGMainPanel")
    sendEvent("QCloseEvent", ":Untitled [modified] - skrooge_SKGMainPanel")
    waitForObject(":Question – Skrooge.Do not save_KPushButton")
    clickButton(":Question – Skrooge.Do not save_KPushButton")
